==> Tagz-1.0.0.zip: Tagz/lang/pt.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Palavras-chave',
 'L_TITLE'=>'Editar palavras-chave do site',
 'L_DESCRIPTION'=>'Gerenciar tags de site. Exclua ou renomeie o conjunto de palavras-chave.',
#admin
 'L_CANCEL'=>'Cancelar tudo',
 'L_DEVIENT'=>'torna-se',
 'L_POUR'=>'para',
 'L_SEARCH'=>'Pesquisa em artigos com esta palavra chave',
 'L_RESTORE'=>'restaurar',
 'L_DEL'=>'apagar',
 'L_RESTORE_ALL'=>'Restaurar todos os campos deixados vazios',
 'L_DEL_ALL'=>'Limpar todos os campos',
 'L_ART_NUM'=>'Para o (s) item (ns) com número (s)',
 'L_HELP_TAG_FIELD'=>'Se o campo estiver vazio, isso exclui a palavra-chave depois de salvar.'.PHP_EOL.'La combinaison de touche Ctrl + z permet d’annuler',
 'L_TAGS_REFRESH'=>'refrescar',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Arquivo tags.xml atualizado pelas palavras-chave dos artigos',
 'L_TAG_PLACEHOLDER'=>'Excluído se deixado vazio',
 'L_DEDUPLICATED'=>'desduplicado',
 'L_IN_REALITY'=>'Na realidade',
 'L_IS_UNIK'=>'Único (é solo)',
 'L_DOUBLES'=>'duplo',
 'L_TRIPLES'=>'triplos',
 'L_QUADRUPLES'=>'quádruplo',
 'L_QUINTUPLES'=>'quíntuplo',
 'L_SEXTUPLES'=>'sêxtuplo',
 'L_SEPTUPLES'=>'sete vezes',
#config
 'L_ACCES'=>'Tipo (s) de conta (s) * autorizado (a) a acessar o plugin',
 'L_HELP_ACCES'=>'Quais perfis * podem usar o plug-in. Lista separada por vírgulas (Padrão PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Usuário (s) proibido (s) de acessar o plugin (menu oculto)',
 'L_HELP_DENY'=>'Quais são os identificadores dos usuários a quem é proibido usar o plugin. Lista separada por vírgula (por exemplo 001,002,007).'
);
?>

==> Tagz-1.0.4.zip: Tagz/lang/pt.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Palavras-chave',
 'L_TITLE'=>'Editar palavras-chave do site',
 'L_DESCRIPTION'=>'Gerenciar tags de site. Exclua ou renomeie o conjunto de palavras-chave.',
 'L_FILTER_TAGS'=>'Filtrar palavras-chave',
 'L_FILTER_TAGS_PH'=>'Filtro de palavras',
 'L_CANCEL'=>'Cancelar tudo',
 'L_DEVIENT'=>'torna-se',
 'L_POUR'=>'para',
 'L_SEARCH'=>'Pesquisa em artigos com esta palavra chave',
 'L_RESTORE'=>'restaurar',
 'L_DEL'=>'apagar',
 'L_RESTORE_ALL'=>'Restaurar todos os campos deixados vazios',
 'L_DEL_ALL'=>'Limpar todos os campos',
 'L_ART_NUM'=>'Para o (s) item (ns) com número (s)',
 'L_HELP_TAG_FIELD'=>'Se o campo estiver vazio, isso exclui a palavra-chave depois de salvar.',
 'L_HELP_TAG_CTRLZ'=>'A combinação de teclas Ctrl-z permite que você cancele',
 'L_TAGS_REFRESH'=>'refrescar',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Arquivo tags.xml atualizado pelas palavras-chave dos artigos',
 'L_TAG_PLACEHOLDER'=>'Excluído se deixado vazio',
 'L_DEDUPLICATED'=>'desduplicado',
 'L_IN_REALITY'=>'Na realidade',
 'L_IS_UNIK'=>'Único (é solo)',
 'L_DOUBLES'=>'duplo',
 'L_TRIPLES'=>'triplos',
 'L_QUADRUPLES'=>'quádruplo',
 'L_QUINTUPLES'=>'quíntuplo',
 'L_SEXTUPLES'=>'sêxtuplo',
 'L_SEPTUPLES'=>'sete vezes',
 'L_OCTUPLES'=>'Octuples',
 'L_NONUPLES'=>'Não-uples',
 'L_DECUPLES'=>'Tenfold',
#config
 'L_ACCES'=>'Tipo (s) de conta (s) * autorizado (a) a acessar o plugin',
 'L_HELP_ACCES'=>'Quais perfis * podem usar o plug-in. Lista separada por vírgulas (Padrão PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Usuário (s) proibido (s) de acessar o plugin (menu oculto)',
 'L_HELP_DENY'=>'Quais são os identificadores dos usuários a quem é proibido usar o plugin. Lista separada por vírgula (por exemplo 001,002,007).',
);
?>
